@@ -354,6 +354,45 @@ class BlockStorage(service.UnifiedService):
                                              description=description,
                                              is_public=is_public)
 
+    @service.should_be_overridden
+    def update_volume_type(self, volume_type, name=None,
+                           description=None, is_public=None):
+        """Update the name and/or description for a volume type.
+
+        :param volume_type: The ID or an instance of the :class:`VolumeType`
+                            to update.
+        :param name: if None, updates name by generating random name.
+                     else updates name with provided name
+        :param description: Description of the volume type.
+        :returns: Returns an updated volume type object.
+        """
+        return self._impl.update_volume_type(
+            volume_type=volume_type, name=name, description=description,
+            is_public=is_public
+        )
+
+    @service.should_be_overridden
+    def add_type_access(self, volume_type, project):
+        """Add a project to the given volume type access list.
+
+        :param volume_type: Volume type name or ID to add access for the given
+                            project
+        :param project: Project ID to add volume type access for
+        :return: An instance of cinderclient.apiclient.base.TupleWithMeta
+        """
+        return self._impl.add_type_access(
+            volume_type=volume_type, project=project
+        )
+
+    @service.should_be_overridden
+    def list_type_access(self, volume_type):
+        """Print access information about the given volume type
+
+        :param volume_type: Filter results by volume type name or ID
+        :return: VolumeTypeAccess of specific project
+        """
+        return self._impl.list_type_access(volume_type)
+
     @service.should_be_overridden
     def get_volume_type(self, volume_type):
         """get details of volume_type.
@@ -433,7 +472,7 @@ class BlockStorage(service.UnifiedService):
 
     @service.should_be_overridden
     def delete_encryption_type(self, volume_type):
-        """Delete the encryption type information for the specified volume type.
+        """Delete the encryption type information for the specified volume type
 
         :param volume_type: the volume type whose encryption type information
                             must be deleted
@@ -442,7 +481,7 @@ class BlockStorage(service.UnifiedService):
 
     @service.should_be_overridden
     def update_encryption_type(self, volume_type, specs):
-        """Update the encryption type information for the specified volume type.
+        """Update the encryption type information for the specified volume type
 
         :param volume_type: the volume type whose encryption type information
                             will be updated
