@@ -22,6 +22,7 @@ from rally_openstack.common.services.image import glance_v2
 from rally_openstack.common.services.image import image
 from rally_openstack.common.services.network import neutron
 from rally_openstack.task.cleanup import base
+from rally_openstack.task.scenarios.nova import utils as nova_utils
 
 
 CONF = cfg.CONF
@@ -144,7 +145,13 @@ _nova_order = get_order(200)
 class NovaServer(base.ResourceManager):
     def list(self):
         """List all servers."""
-        return self._manager().list(limit=-1)
+        clients = (self._admin_required and self.admin or self.user)
+        nc = getattr(clients, self._service)()
+        return nova_utils.list_servers(
+            nc,
+            # we need details to get locked states
+            detailed=True
+        )
 
     def delete(self):
         if getattr(self.raw_resource, "OS-EXT-STS:locked", False):
@@ -431,7 +438,8 @@ class NeutronPort(NeutronMixin):
 
     def _get_resources(self, resource):
         if resource not in self._cache:
-            resources = getattr(self._neutron, "list_%s" % resource)()
+            getter = getattr(self._neutron, "list_%s" % resource)
+            resources = getter(tenant_id=self.tenant_uuid)
             self._cache[resource] = [r for r in resources
                                      if r["tenant_id"] == self.tenant_uuid]
         return self._cache[resource]
