@@ -76,13 +76,22 @@ class MagnumMixinTestCase(test.TestCase):
 
 class NovaServerTestCase(test.TestCase):
 
-    def test_list(self):
-        server = resources.NovaServer()
-        server._manager = mock.MagicMock()
+    @mock.patch(BASE + ".nova_utils.list_servers")
+    def test_list(self, mock_list_servers):
 
-        server.list()
+        user_clients = mock.Mock()
+        admin_clients = mock.Mock()
 
-        server._manager.return_value.list.assert_called_once_with(limit=-1)
+        servers_res = resources.NovaServer(
+            admin=admin_clients, user=user_clients
+        )
+
+        self.assertEqual(
+            mock_list_servers.return_value,
+            servers_res.list()
+        )
+        mock_list_servers.assert_called_once_with(user_clients.nova(),
+                                                  detailed=True)
 
     def test_delete(self):
         server = resources.NovaServer()
@@ -460,7 +469,8 @@ class NeutronPortTestCase(test.TestCase):
             {"tenant_id": tenant_uuid, "id": "id7",
              "device_owner": "network:dhcp",
              "device_id": "asdasdasd"},
-            # the case when port is from another tenant
+            # the case when port is from another tenant. it should not be
+            #   here as we are filtering by tenant id, but anyway.
             {"tenant_id": "wrong tenant", "id": "id8", "name": "foo"},
             # WTF port without any parent and name
             {"tenant_id": tenant_uuid, "id": "id9", "device_owner": ""},
@@ -496,8 +506,8 @@ class NeutronPortTestCase(test.TestCase):
         user = mock.Mock(neutron=neutron)
         self.assertEqual(expected_ports, resources.NeutronPort(
             user=user, tenant_uuid=tenant_uuid).list())
-        neutron.list_ports.assert_called_once_with()
-        neutron.list_routers.assert_called_once_with()
+        neutron.list_ports.assert_called_once_with(tenant_id=tenant_uuid)
+        neutron.list_routers.assert_called_once_with(tenant_id=tenant_uuid)
 
 
 @ddt.ddt
